==> accounts_management-0.1.6.gem: app/controllers/accounts_management/ledgers/master_data_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::MasterDataController < AccountsManagementController
    # GET /ledgers/master_data
    # GET /ledgers/master_data.json
    def index
      @ledgers_master_data = Ledgers::MasterData.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @ledgers_master_data }
      end
    end

    # GET /ledgers/master_data/1
    # GET /ledgers/master_data/1.json
    def show
      @ledgers_master_data = Ledgers::MasterData.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @ledgers_master_data }
      end
    end

    # GET /ledgers/master_data/new
    # GET /ledgers/master_data/new.json
    def new
      @ledgers_master_data = Ledgers::MasterData.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @ledgers_master_data }
      end
    end

    # GET /ledgers/master_data/1/edit
    def edit
      @ledgers_master_data = Ledgers::MasterData.find(params[:id])
    end

    # POST /ledgers/master_data
    # POST /ledgers/master_data.json
    def create
      @ledgers_master_data = Ledgers::MasterData.new(params[:ledgers_master_data])

      respond_to do |format|
        if @ledgers_master_data.save
          format.html { redirect_to @ledgers_master_data, :notice => 'Master data was successfully created.' }
          format.json { render :json => @ledgers_master_data, :status => :created, :location => @ledgers_master_data }
        else
          format.html { render :action => "new" }
          format.json { render :json => @ledgers_master_data.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/master_data/1
    # PUT /ledgers/master_data/1.json
    def update
      @ledgers_master_data = Ledgers::MasterData.find(params[:id])

      respond_to do |format|
        if @ledgers_master_data.update_attributes(params[:ledgers_master_data])
          format.html { redirect_to @ledgers_master_data, :notice => 'Master data was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @ledgers_master_data.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/master_data/1
    # DELETE /ledgers/master_data/1.json
    def destroy
      @ledgers_master_data = Ledgers::MasterData.find(params[:id])
      @ledgers_master_data.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_master_data_index_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/ledgers/master_data_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::MasterDataController < AccountsManagementController
    # GET /ledgers/master_data
    # GET /ledgers/master_data.json
    def index
      @ledgers_master_data = Ledgers::MasterData.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @ledgers_master_data }
      end
    end

    # GET /ledgers/master_data/1
    # GET /ledgers/master_data/1.json
    def show
      @ledgers_master_data = Ledgers::MasterData.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @ledgers_master_data }
      end
    end

    # GET /ledgers/master_data/new
    # GET /ledgers/master_data/new.json
    def new
      @ledgers_master_data = Ledgers::MasterData.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @ledgers_master_data }
      end
    end

    # GET /ledgers/master_data/1/edit
    def edit
      @ledgers_master_data = Ledgers::MasterData.find(params[:id])
    end

    # POST /ledgers/master_data
    # POST /ledgers/master_data.json
    def create
      @ledgers_master_data = Ledgers::MasterData.new(params[:ledgers_master_data])

      respond_to do |format|
        if @ledgers_master_data.save
          format.html { redirect_to @ledgers_master_data, notice: 'Master data was successfully created.' }
          format.json { render json: @ledgers_master_data, status: :created, location: @ledgers_master_data }
        else
          format.html { render action: "new" }
          format.json { render json: @ledgers_master_data.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/master_data/1
    # PUT /ledgers/master_data/1.json
    def update
      @ledgers_master_data = Ledgers::MasterData.find(params[:id])

      respond_to do |format|
        if @ledgers_master_data.update_attributes(params[:ledgers_master_data])
          format.html { redirect_to @ledgers_master_data, notice: 'Master data was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @ledgers_master_data.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/master_data/1
    # DELETE /ledgers/master_data/1.json
    def destroy
      @ledgers_master_data = Ledgers::MasterData.find(params[:id])
      @ledgers_master_data.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_master_data_index_url }
        format.json { head :no_content }
      end
    end
  end
end
